package com.persagy.apm.energy.report.common.utils;

import com.persagy.apm.energy.report.monthly.detail.common.model.vo.DateGraphItemVO;
import org.springframework.util.CollectionUtils;

import java.util.*;

/**
 * 图表数据工具类
 *
 * @author lixing
 * @version V1.0 2022/4/26 17:24
 **/
public class GraphDataUtils {

    /**
     * 获取一组图表数据中最大或最小数对应的日期列表
     *
     * @param dateGraphItemVOList 一组图表数据
     * @param orderType （-1：从高到低，1: 从低到高）
     * @return 一组图表数据中最大或最小数对应的日期列表
     * @author lixing 2022/4/26 17:26
     */
    public static List<Date> getMaxOrMinDateList(List<DateGraphItemVO> dateGraphItemVOList, Integer orderType) {
        if (CollectionUtils.isEmpty(dateGraphItemVOList)) {
            return new ArrayList<>();
        }
        List<DateGraphItemVO> dataList = new ArrayList<>();
        for (DateGraphItemVO vo : dateGraphItemVOList) {
            if (vo.getValue() == null) {
                continue;
            }
            dataList.add(vo);
        }
        Map<String, Integer> sortMap = new HashMap<>();
        sortMap.put("value", orderType);
        DataUtils.sort(dataList, sortMap);
        List<Date> resultList = new ArrayList<>();
        Double maxOrMinData = null;
        for (DateGraphItemVO vo : dataList) {
            if (vo.getValue() == null) {
                continue;
            }
            if (maxOrMinData == null) {
                maxOrMinData = vo.getValue();
            } else if (maxOrMinData.compareTo(vo.getValue()) != 0) {
                break;
            }
            resultList.add(vo.getDate());
        }
        return resultList;
    }
}
